Overview: module code — django-tables2 1.4.1 documentation

# All modules for which code is available

- django_tables2.columns.base
- django_tables2.columns.booleancolumn
- django_tables2.columns.checkboxcolumn
- django_tables2.columns.datecolumn
- django_tables2.columns.datetimecolumn
- django_tables2.columns.emailcolumn
- django_tables2.columns.filecolumn
- django_tables2.columns.linkcolumn
- django_tables2.columns.templatecolumn
- django_tables2.columns.urlcolumn
- django_tables2.config
- django_tables2.rows
- django_tables2.tables
- django_tables2.utils
- django_tables2.views